@@ -28,9 +28,7 @@
 #endif
 
 #include <gtk/gtk.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
 #include <gtk/gtkx.h>
-#endif
 #include <glib.h>
 #include <libxfce4util/libxfce4util.h>
 
@@ -95,6 +93,8 @@ static void          xfce_panel_plugin_set_size               (XfcePanelPluginPr
                                                                gint                              size);
 static void          xfce_panel_plugin_set_icon_size          (XfcePanelPluginProvider          *provider,
                                                                gint                              icon_size);
+static void          xfce_panel_plugin_set_dark_mode          (XfcePanelPluginProvider          *provider,
+                                                               gboolean                          dark_mode);
 static void          xfce_panel_plugin_set_mode               (XfcePanelPluginProvider          *provider,
                                                                XfcePanelPluginMode               mode);
 static void          xfce_panel_plugin_set_nrows              (XfcePanelPluginProvider          *provider,
@@ -132,6 +132,7 @@ enum
   PROP_ORIENTATION,
   PROP_SIZE,
   PROP_ICON_SIZE,
+  PROP_DARK_MODE,
   PROP_SMALL,
   PROP_SCREEN_POSITION,
   PROP_EXPAND,
@@ -179,6 +180,7 @@ struct _XfcePanelPluginPrivate
   gchar              **arguments;
   gint                 size; /* single row size */
   gint                 icon_size;
+  gboolean             dark_mode;
   guint                expand : 1;
   guint                shrink : 1;
   guint                nrows;
@@ -592,6 +594,22 @@ xfce_panel_plugin_class_init (XfcePanelPluginClass *klass)
                         G_PARAM_READABLE
                         | G_PARAM_STATIC_STRINGS);
 
+  /**
+   * XfcePanelPlugin:dark-mode:
+   *
+   * Whether the #XfcePanelPlugin shall request the Gtk dark theme variant (based on the panel
+   * setting).
+   *
+   * Since: 4.14
+   **/
+  plugin_props[PROP_DARK_MODE] =
+      g_param_spec_boolean ("dark-mode",
+                            "Dark Mode",
+                            "Whether or not to request the Gtk dark theme variant",
+                            FALSE,
+                            G_PARAM_READWRITE
+                            | G_PARAM_STATIC_STRINGS);
+
   /**
    * XfcePanelPlugin:screen-position:
    *
@@ -710,6 +728,7 @@ xfce_panel_plugin_init (XfcePanelPlugin *plugin)
   plugin->priv->arguments = NULL;
   plugin->priv->size = 0;
   plugin->priv->icon_size = 0;
+  plugin->priv->dark_mode = FALSE;
   plugin->priv->small = FALSE;
   plugin->priv->expand = FALSE;
   plugin->priv->shrink = FALSE;
@@ -746,6 +765,7 @@ xfce_panel_plugin_provider_init (XfcePanelPluginProviderInterface *iface)
   iface->get_unique_id = (ProviderToPluginInt) xfce_panel_plugin_get_unique_id;
   iface->set_size = xfce_panel_plugin_set_size;
   iface->set_icon_size = xfce_panel_plugin_set_icon_size;
+  iface->set_dark_mode = xfce_panel_plugin_set_dark_mode;
   iface->set_mode = xfce_panel_plugin_set_mode;
   iface->set_nrows = xfce_panel_plugin_set_nrows;
   iface->set_screen_position = xfce_panel_plugin_set_screen_position;
@@ -821,6 +841,10 @@ xfce_panel_plugin_get_property (GObject    *object,
       g_value_set_uint (value, private->icon_size);
       break;
 
+    case PROP_DARK_MODE:
+      g_value_set_boolean (value, private->dark_mode);
+      break;
+
     case PROP_NROWS:
       g_value_set_uint (value, private->nrows);
       break;
@@ -892,6 +916,11 @@ xfce_panel_plugin_set_property (GObject      *object,
       private->arguments = g_value_dup_boxed (value);
       break;
 
+    case PROP_DARK_MODE:
+      xfce_panel_plugin_set_dark_mode (XFCE_PANEL_PLUGIN_PROVIDER (object),
+                                       g_value_get_boolean (value));
+      break;
+
     case PROP_SMALL:
       xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (object),
                                    g_value_get_boolean (value));
@@ -1026,12 +1055,7 @@ xfce_panel_plugin_button_press_event (GtkWidget      *widget,
         gtk_widget_set_sensitive (item, plugin->priv->menu_blocked == 0);
 
       /* popup the menu */
-#if GTK_CHECK_VERSION (3, 0, 0)
       gtk_menu_popup_at_pointer (menu, (GdkEvent *) event);
-#else
-      gtk_menu_popup (menu, NULL, NULL, NULL, NULL,
-                      event->button, event->time);
-#endif
       return TRUE;
     }
 
@@ -1373,7 +1397,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
       gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
       gtk_widget_show (item);
 
-      image = gtk_image_new_from_icon_name ("help-browser", GTK_ICON_SIZE_MENU);
+      image = gtk_image_new_from_icon_name ("gtk-help", GTK_ICON_SIZE_MENU);
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 G_GNUC_END_IGNORE_DEPRECATIONS
@@ -1496,6 +1520,35 @@ xfce_panel_plugin_set_icon_size (XfcePanelPluginProvider *provider,
 
 
 
+static void
+xfce_panel_plugin_set_dark_mode (XfcePanelPluginProvider *provider,
+                                 gboolean                 dark_mode)
+{
+#if GTK_CHECK_VERSION (3, 0, 0)
+  XfcePanelPlugin *plugin = XFCE_PANEL_PLUGIN (provider);
+  GtkSettings *gtk_settings;
+
+  if (G_LIKELY (plugin->priv->dark_mode != dark_mode))
+    {
+      plugin->priv->dark_mode = dark_mode;
+      g_object_notify_by_pspec (G_OBJECT (plugin), plugin_props[PROP_DARK_MODE]);
+
+      gtk_settings = gtk_widget_get_settings (GTK_WIDGET (plugin));
+
+      if (!dark_mode)
+        gtk_settings_reset_property (gtk_settings,
+                                     "gtk-application-prefer-dark-theme");
+
+      g_object_set (gtk_settings,
+                    "gtk-application-prefer-dark-theme",
+                    dark_mode,
+                    NULL);
+    }
+#endif
+}
+
+
+
 static void
 xfce_panel_plugin_set_mode (XfcePanelPluginProvider *provider,
                             XfcePanelPluginMode      mode)
@@ -2501,12 +2554,8 @@ xfce_panel_plugin_arrow_type (XfcePanelPlugin *plugin)
 {
   XfceScreenPosition  screen_position;
   GdkScreen          *screen;
-#if GTK_CHECK_VERSION (3, 0, 0)
   GdkDisplay         *display;
   GdkMonitor         *monitor;
-#else
-  gint                monitor_num;
-#endif
   GdkRectangle        geometry;
   gint                x, y;
   GdkWindow          *window;
@@ -2534,14 +2583,10 @@ xfce_panel_plugin_arrow_type (XfcePanelPlugin *plugin)
 
       /* get the monitor geometry */
       screen = gtk_widget_get_screen (GTK_WIDGET (plugin));
-#if GTK_CHECK_VERSION (3, 0, 0)
       display = gdk_screen_get_display (screen);
       monitor = gdk_display_get_monitor_at_window (display, window);
       gdk_monitor_get_geometry (monitor, &geometry);
-#else
-      monitor_num = gdk_screen_get_monitor_at_window (screen, window);
-      gdk_screen_get_monitor_geometry (screen, monitor_num, &geometry);
-#endif
+
       /* get the plugin root origin */
       gdk_window_get_root_origin (window, &x, &y);
 
@@ -2583,12 +2628,8 @@ xfce_panel_plugin_position_widget (XfcePanelPlugin *plugin,
   GtkRequisition  requisition;
   GdkScreen      *screen;
   GdkRectangle    geometry;
-#if GTK_CHECK_VERSION (3, 0, 0)
   GdkDisplay     *display;
   GdkMonitor     *monitor;
-#else
-  gint            monitor_num;
-#endif
   GTimeVal        now_t, end_t;
   GtkWidget      *toplevel, *plug;
   gint            px, py;
@@ -2612,11 +2653,7 @@ xfce_panel_plugin_position_widget (XfcePanelPlugin *plugin,
     gtk_widget_realize (attach_widget);
 
   /* get the menu/widget size request */
-#if GTK_CHECK_VERSION (3, 0, 0)
   gtk_widget_get_preferred_size (menu_widget, &requisition, NULL);
-#else
-  gtk_widget_size_request (menu_widget, &requisition);
-#endif
 
   /* get the root position of the attach widget */
   toplevel = gtk_widget_get_toplevel (attach_widget);
@@ -2626,14 +2663,8 @@ xfce_panel_plugin_position_widget (XfcePanelPlugin *plugin,
   plug = gtk_widget_get_ancestor (attach_widget, GTK_TYPE_PLUG);
   if (plug != NULL)
     {
-#if GTK_CHECK_VERSION (3, 0, 0)
        gdk_window_get_geometry (gtk_plug_get_socket_window (GTK_PLUG (plug)),
                                 &px, &py, NULL, NULL);
-#else
-       gdk_window_get_geometry (gtk_plug_get_socket_window (GTK_PLUG (plug)),
-                                &px, &py, NULL, NULL, NULL);
-#endif
-
        *x += px;
        *y += py;
     }
@@ -2688,14 +2719,9 @@ xfce_panel_plugin_position_widget (XfcePanelPlugin *plugin,
 
   /* get the monitor geometry */
   screen = gtk_widget_get_screen (attach_widget);
-#if GTK_CHECK_VERSION (3, 0, 0)
   display = gdk_screen_get_display (screen);
   monitor = gdk_display_get_monitor_at_window (display, gtk_widget_get_window (attach_widget));
   gdk_monitor_get_geometry (monitor, &geometry);
-#else
-  monitor_num = gdk_screen_get_monitor_at_window (screen, gtk_widget_get_window (attach_widget));
-  gdk_screen_get_monitor_geometry (screen, monitor_num, &geometry);
-#endif
 
   /* keep the menu inside the screen */
   if (*x > geometry.x + geometry.width - requisition.width)
@@ -2772,15 +2798,10 @@ xfce_panel_plugin_position_menu (GtkMenu  *menu,
   xfce_panel_plugin_position_widget (XFCE_PANEL_PLUGIN (panel_plugin),
                                      GTK_WIDGET (menu), attach_widget, x, y);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   /* FIXME */
   /* A workaround for Gtk3 popup menus with scroll buttons */
   /* Menus are "pushed in" anyway */
   *push_in = FALSE;
-#else
-  /* keep the menu inside screen */
-  *push_in = TRUE;
-#endif
 }
 
 
@@ -2816,13 +2837,13 @@ xfce_panel_plugin_focus_widget (XfcePanelPlugin *plugin,
  * @plugin  : an #XfcePanelPlugin.
  * @blocked : new blocking state of this plugin.
  *
- * Wether this plugin blocks the autohide functality of the panel. Use
+ * Whether this plugin blocks the autohide functionality of the panel. Use
  * this when you 'popup' something that is visually attached to the
  * plugin at it will look weird for a user if the panel will hide while
  * he/she is working in the popup.
  *
- * For menus it there is xfce_panel_plugin_register_menu() which will
- * take care of this.
+ * For menus use xfce_panel_plugin_register_menu() which will take care
+ * of this.
  **/
 void
 xfce_panel_plugin_block_autohide (XfcePanelPlugin *plugin,
